package com.hai.service.impl;

import com.hai.dao.BsMsgMapper;
import com.hai.dao.BsMsgUserMapper;
import com.hai.entity.*;
import com.hai.service.BsMsgService;
import org.apache.commons.collections4.MapUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.beans.Transient;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.jar.JarEntry;

/**
 * @author sum1dream
 */
@Service("bsMsgService")
public class BsMsgServiceImpl implements BsMsgService {

    @Resource
    private BsMsgMapper bsMsgMapper;

    @Resource
    private BsMsgUserMapper bsMsgUserMapper;

    @Override
    @Transactional
    public void insertMsg(BsMsg bsMsg , HighUser user) {

        bsMsg.setStatus(1);
        bsMsg.setCreateTime(new Date());
        bsMsg.setUpdateTime(new Date());

        bsMsgMapper.insert(bsMsg);
        if (bsMsg.getMsgType()==1){
            BsMsgUser bsMsgUser = new BsMsgUser();
            bsMsgUser.setCreateTime(new Date());
            bsMsgUser.setUpdateTime(new Date());
            bsMsgUser.setMsgId(bsMsg.getId());
            bsMsgUser.setUserName(user.getName());
            bsMsgUser.setUserId(user.getId());
            bsMsgUser.setUserPhone(user.getPhone());
            bsMsgUser.setWhereCheck(false);
            bsMsgUserMapper.insert(bsMsgUser);
        }
    }

    @Override
    public void updateMsg(BsMsg bsMsg) {
        bsMsgMapper.updateByPrimaryKey(bsMsg);
    }

    @Override
    public BsMsg findMsg(Long id) {
        return bsMsgMapper.selectByPrimaryKey(id);
    }

    @Override
    public List<BsMsg> getMsgByList(Map<String, Object> map) {

        BsMsgExample example = new BsMsgExample();
        BsMsgExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getInteger(map , "type") != null) {
            criteria.andTypeEqualTo(MapUtils.getInteger(map , "type"));
        }
        if (MapUtils.getInteger(map , "jumpType") != null) {
            criteria.andJumpTypeEqualTo(MapUtils.getInteger(map , "jumpType"));
        }
        if (MapUtils.getInteger(map , "msgType") != null) {
            criteria.andMsgTypeEqualTo(MapUtils.getInteger(map , "msgType"));
        }
        if (MapUtils.getInteger(map , "title") != null) {
            criteria.andTitleLike("%" + MapUtils.getString(map , "title") + "%" );
        }
        if (MapUtils.getLong(map , "companyId") != null) {
            criteria.andCompanyIdEqualTo(MapUtils.getLong(map , "companyId"));
        }
        if (MapUtils.getInteger(map , "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map , "status"));
        } else {
            criteria.andStatusNotEqualTo(0);
        }

        return bsMsgMapper.selectByExample(example);
    }

    @Override
    public void checkMsg(HighUser user, Long msgId) {
        // 查询用户相关站内信内容
        List<BsMsgUser> list = findMsgUserById(user.getId() , msgId);
        BsMsgUser bsMsgUser = new BsMsgUser();
        // 判读是否有呢日
        if (list.size()>0) {
            bsMsgUser = list.get(0);
            // 判断当前内容是否已经查看过了
            if (!bsMsgUser.getWhereCheck()) {
                bsMsgUser.setWhereCheck(true);
                bsMsgUser.setCheckTime(new Date());
            }
            bsMsgUser.setUpdateTime(new Date());
            bsMsgUserMapper.updateByPrimaryKey(bsMsgUser);
        } else {
            bsMsgUser.setUserId(user.getId());
            bsMsgUser.setMsgId(msgId);
            bsMsgUser.setUserName(user.getName());
            bsMsgUser.setUserPhone(user.getPhone());
            bsMsgUser.setWhereCheck(true);
            bsMsgUser.setCheckTime(new Date());
            bsMsgUser.setCreateTime(new Date());
            bsMsgUser.setUpdateTime(new Date());
            bsMsgUserMapper.insert(bsMsgUser);
        }

    }

    @Override
    public List<BsMsgUser> findMsgUserById(Long userId, Long msgId) {
        BsMsgUserExample example = new BsMsgUserExample();
        BsMsgUserExample.Criteria criteria = example.createCriteria();

        criteria.andUserIdEqualTo(userId).andMsgIdEqualTo(msgId);

        return bsMsgUserMapper.selectByExample(example);
    }
}
